| pkg_template | R Documentation |
This function copies a package template into a new directory. The template includes a DESCRIPTION file, a minimal R/ directory and placeholders with instructions. You can then edit these files to customize your new package.
pkg_template(path = NULL, pkgname = NULL)
path |
Path to the new project |
pkgname |
Name of the new package |
The file path to the copied template (invisibly).
# create a new directory
dir <- tempdir()
dir.create(dir)
# copy the package template into the directory
pkg_template(dir, "mynewpkg")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.